@@ -16,7 +16,17 @@ class productOperator extends entityDatabaseOperator{
         return ['updateEntityData' => true, 'data' => $entity];
     }
 
-    public function getProductNameCache(){
+    public function getByIdOrCode($id)
+    {
+        $entity = $this->vault->select($this->dbTable)->fields('*')->where('id', $id)->execute()->fetchAssoc();
+        if (!$entity) {
+            $entity = $this->vault->select($this->dbTable)->fields('*')->where('code', $id)->execute()->fetchAssoc();
+        }
+
+        return $entity;
+    }
+
+    public function getProductNameCache($index='id'){
         $rows = $this->vault
             ->select($this->dbTable)
             ->fields($this->dbTable.'.*')
@@ -25,7 +35,7 @@ class productOperator extends entityDatabaseOperator{
 
         $productNames = [];
         foreach ($rows as $row) {
-            $productNames[$row->id] = $row->product_name;
+            $productNames[$row->$index] = $row->product_name;
         }
 
         return $productNames;
